@@ -1,7 +1,7 @@
 // Copyright 2019 The Gitea Authors. All rights reserved.
 // SPDX-License-Identifier: MIT
 
-package v1_10 //nolint
+package v1_10
 
 import "xorm.io/xorm"
 
@@ -11,7 +11,7 @@ func AddIndexOnRepositoryAndComment(x *xorm.Engine) error {
 		OwnerID int64 `xorm:"index"`
 	}
 
-	if err := x.Sync2(new(Repository)); err != nil {
+	if err := x.Sync(new(Repository)); err != nil {
 		return err
 	}
 
@@ -21,5 +21,5 @@ func AddIndexOnRepositoryAndComment(x *xorm.Engine) error {
 		ReviewID int64 `xorm:"index"`
 	}
 
-	return x.Sync2(new(Comment))
+	return x.Sync(new(Comment))
 }
