@@ -1,7 +1,7 @@
 // Copyright 2024 The Gitea Authors. All rights reserved.
 // SPDX-License-Identifier: MIT
 
-package v1_22 //nolint
+package v1_22
 
 // NOTE: noop the original migration has bug which some projects will be skip, so
 // these projects will have no default board.
