@@ -6,7 +6,6 @@ package repo_test
 import (
 	"testing"
 
-	"code.gitea.io/gitea/models/db"
 	repo_model "code.gitea.io/gitea/models/repo"
 	"code.gitea.io/gitea/models/unittest"
 
@@ -16,15 +15,15 @@ import (
 func TestIncreaseDownloadCount(t *testing.T) {
 	assert.NoError(t, unittest.PrepareTestDatabase())
 
-	attachment, err := repo_model.GetAttachmentByUUID(db.DefaultContext, "a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11")
+	attachment, err := repo_model.GetAttachmentByUUID(t.Context(), "a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11")
 	assert.NoError(t, err)
 	assert.Equal(t, int64(0), attachment.DownloadCount)
 
 	// increase download count
-	err = attachment.IncreaseDownloadCount(db.DefaultContext)
+	err = attachment.IncreaseDownloadCount(t.Context())
 	assert.NoError(t, err)
 
-	attachment, err = repo_model.GetAttachmentByUUID(db.DefaultContext, "a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11")
+	attachment, err = repo_model.GetAttachmentByUUID(t.Context(), "a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11")
 	assert.NoError(t, err)
 	assert.Equal(t, int64(1), attachment.DownloadCount)
 }
@@ -33,11 +32,11 @@ func TestGetByCommentOrIssueID(t *testing.T) {
 	assert.NoError(t, unittest.PrepareTestDatabase())
 
 	// count of attachments from issue ID
-	attachments, err := repo_model.GetAttachmentsByIssueID(db.DefaultContext, 1)
+	attachments, err := repo_model.GetAttachmentsByIssueID(t.Context(), 1)
 	assert.NoError(t, err)
 	assert.Len(t, attachments, 1)
 
-	attachments, err = repo_model.GetAttachmentsByCommentID(db.DefaultContext, 1)
+	attachments, err = repo_model.GetAttachmentsByCommentID(t.Context(), 1)
 	assert.NoError(t, err)
 	assert.Len(t, attachments, 2)
 }
@@ -45,18 +44,18 @@ func TestGetByCommentOrIssueID(t *testing.T) {
 func TestDeleteAttachments(t *testing.T) {
 	assert.NoError(t, unittest.PrepareTestDatabase())
 
-	count, err := repo_model.DeleteAttachmentsByIssue(db.DefaultContext, 4, false)
+	count, err := repo_model.DeleteAttachmentsByIssue(t.Context(), 4, false)
 	assert.NoError(t, err)
 	assert.Equal(t, 2, count)
 
-	count, err = repo_model.DeleteAttachmentsByComment(db.DefaultContext, 2, false)
+	count, err = repo_model.DeleteAttachmentsByComment(t.Context(), 2, false)
 	assert.NoError(t, err)
 	assert.Equal(t, 2, count)
 
-	err = repo_model.DeleteAttachment(db.DefaultContext, &repo_model.Attachment{ID: 8}, false)
+	err = repo_model.DeleteAttachment(t.Context(), &repo_model.Attachment{ID: 8}, false)
 	assert.NoError(t, err)
 
-	attachment, err := repo_model.GetAttachmentByUUID(db.DefaultContext, "a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a18")
+	attachment, err := repo_model.GetAttachmentByUUID(t.Context(), "a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a18")
 	assert.Error(t, err)
 	assert.True(t, repo_model.IsErrAttachmentNotExist(err))
 	assert.Nil(t, attachment)
@@ -65,7 +64,7 @@ func TestDeleteAttachments(t *testing.T) {
 func TestGetAttachmentByID(t *testing.T) {
 	assert.NoError(t, unittest.PrepareTestDatabase())
 
-	attach, err := repo_model.GetAttachmentByID(db.DefaultContext, 1)
+	attach, err := repo_model.GetAttachmentByID(t.Context(), 1)
 	assert.NoError(t, err)
 	assert.Equal(t, "a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11", attach.UUID)
 }
@@ -81,12 +80,12 @@ func TestAttachment_DownloadURL(t *testing.T) {
 func TestUpdateAttachment(t *testing.T) {
 	assert.NoError(t, unittest.PrepareTestDatabase())
 
-	attach, err := repo_model.GetAttachmentByID(db.DefaultContext, 1)
+	attach, err := repo_model.GetAttachmentByID(t.Context(), 1)
 	assert.NoError(t, err)
 	assert.Equal(t, "a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11", attach.UUID)
 
 	attach.Name = "new_name"
-	assert.NoError(t, repo_model.UpdateAttachment(db.DefaultContext, attach))
+	assert.NoError(t, repo_model.UpdateAttachment(t.Context(), attach))
 
 	unittest.AssertExistsAndLoadBean(t, &repo_model.Attachment{Name: "new_name"})
 }
@@ -94,7 +93,7 @@ func TestUpdateAttachment(t *testing.T) {
 func TestGetAttachmentsByUUIDs(t *testing.T) {
 	assert.NoError(t, unittest.PrepareTestDatabase())
 
-	attachList, err := repo_model.GetAttachmentsByUUIDs(db.DefaultContext, []string{"a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11", "a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a17", "not-existing-uuid"})
+	attachList, err := repo_model.GetAttachmentsByUUIDs(t.Context(), []string{"a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11", "a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a17", "not-existing-uuid"})
 	assert.NoError(t, err)
 	assert.Len(t, attachList, 2)
 	assert.Equal(t, "a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11", attachList[0].UUID)
