@@ -6,7 +6,6 @@ package repo
 import (
 	"testing"
 
-	"code.gitea.io/gitea/models/db"
 	"code.gitea.io/gitea/modules/setting"
 	"code.gitea.io/gitea/modules/test"
 
@@ -18,11 +17,11 @@ func TestRepoAvatarLink(t *testing.T) {
 	defer test.MockVariableValue(&setting.AppSubURL, "")()
 
 	repo := &Repository{ID: 1, Avatar: "avatar.png"}
-	link := repo.AvatarLink(db.DefaultContext)
+	link := repo.AvatarLink(t.Context())
 	assert.Equal(t, "https://localhost/repo-avatars/avatar.png", link)
 
 	setting.AppURL = "https://localhost/sub-path/"
 	setting.AppSubURL = "/sub-path"
-	link = repo.AvatarLink(db.DefaultContext)
+	link = repo.AvatarLink(t.Context())
 	assert.Equal(t, "https://localhost/sub-path/repo-avatars/avatar.png", link)
 }
