@@ -6,7 +6,6 @@ package repo
 import (
 	"testing"
 
-	"code.gitea.io/gitea/models/db"
 	"code.gitea.io/gitea/models/unittest"
 
 	"github.com/stretchr/testify/assert"
@@ -22,14 +21,14 @@ func TestMigrate_InsertReleases(t *testing.T) {
 		Attachments: []*Attachment{a},
 	}
 
-	err := InsertReleases(db.DefaultContext, r)
+	err := InsertReleases(t.Context(), r)
 	assert.NoError(t, err)
 }
 
 func Test_FindTagsByCommitIDs(t *testing.T) {
 	assert.NoError(t, unittest.PrepareTestDatabase())
 
-	sha1Rels, err := FindTagsByCommitIDs(db.DefaultContext, 1, "65f1bf27bc3bf70f64657658635e66094edbcb4d")
+	sha1Rels, err := FindTagsByCommitIDs(t.Context(), 1, "65f1bf27bc3bf70f64657658635e66094edbcb4d")
 	assert.NoError(t, err)
 	assert.Len(t, sha1Rels, 1)
 	rels := sha1Rels["65f1bf27bc3bf70f64657658635e66094edbcb4d"]
