@@ -21,25 +21,25 @@ func TestStarRepo(t *testing.T) {
 	repo := unittest.AssertExistsAndLoadBean(t, &repo_model.Repository{ID: 1})
 
 	unittest.AssertNotExistsBean(t, &repo_model.Star{UID: user.ID, RepoID: repo.ID})
-	assert.NoError(t, repo_model.StarRepo(db.DefaultContext, user, repo, true))
+	assert.NoError(t, repo_model.StarRepo(t.Context(), user, repo, true))
 	unittest.AssertExistsAndLoadBean(t, &repo_model.Star{UID: user.ID, RepoID: repo.ID})
-	assert.NoError(t, repo_model.StarRepo(db.DefaultContext, user, repo, true))
+	assert.NoError(t, repo_model.StarRepo(t.Context(), user, repo, true))
 	unittest.AssertExistsAndLoadBean(t, &repo_model.Star{UID: user.ID, RepoID: repo.ID})
-	assert.NoError(t, repo_model.StarRepo(db.DefaultContext, user, repo, false))
+	assert.NoError(t, repo_model.StarRepo(t.Context(), user, repo, false))
 	unittest.AssertNotExistsBean(t, &repo_model.Star{UID: user.ID, RepoID: repo.ID})
 }
 
 func TestIsStaring(t *testing.T) {
 	assert.NoError(t, unittest.PrepareTestDatabase())
-	assert.True(t, repo_model.IsStaring(db.DefaultContext, 2, 4))
-	assert.False(t, repo_model.IsStaring(db.DefaultContext, 3, 4))
+	assert.True(t, repo_model.IsStaring(t.Context(), 2, 4))
+	assert.False(t, repo_model.IsStaring(t.Context(), 3, 4))
 }
 
 func TestRepository_GetStargazers(t *testing.T) {
 	// repo with stargazers
 	assert.NoError(t, unittest.PrepareTestDatabase())
 	repo := unittest.AssertExistsAndLoadBean(t, &repo_model.Repository{ID: 4})
-	gazers, err := repo_model.GetStargazers(db.DefaultContext, repo, db.ListOptions{Page: 0})
+	gazers, err := repo_model.GetStargazers(t.Context(), repo, db.ListOptions{Page: 0})
 	assert.NoError(t, err)
 	if assert.Len(t, gazers, 1) {
 		assert.Equal(t, int64(2), gazers[0].ID)
@@ -50,7 +50,7 @@ func TestRepository_GetStargazers2(t *testing.T) {
 	// repo with stargazers
 	assert.NoError(t, unittest.PrepareTestDatabase())
 	repo := unittest.AssertExistsAndLoadBean(t, &repo_model.Repository{ID: 3})
-	gazers, err := repo_model.GetStargazers(db.DefaultContext, repo, db.ListOptions{Page: 0})
+	gazers, err := repo_model.GetStargazers(t.Context(), repo, db.ListOptions{Page: 0})
 	assert.NoError(t, err)
 	assert.Empty(t, gazers)
 }
@@ -62,14 +62,14 @@ func TestClearRepoStars(t *testing.T) {
 	repo := unittest.AssertExistsAndLoadBean(t, &repo_model.Repository{ID: 1})
 
 	unittest.AssertNotExistsBean(t, &repo_model.Star{UID: user.ID, RepoID: repo.ID})
-	assert.NoError(t, repo_model.StarRepo(db.DefaultContext, user, repo, true))
+	assert.NoError(t, repo_model.StarRepo(t.Context(), user, repo, true))
 	unittest.AssertExistsAndLoadBean(t, &repo_model.Star{UID: user.ID, RepoID: repo.ID})
-	assert.NoError(t, repo_model.StarRepo(db.DefaultContext, user, repo, false))
+	assert.NoError(t, repo_model.StarRepo(t.Context(), user, repo, false))
 	unittest.AssertNotExistsBean(t, &repo_model.Star{UID: user.ID, RepoID: repo.ID})
-	assert.NoError(t, repo_model.ClearRepoStars(db.DefaultContext, repo.ID))
+	assert.NoError(t, repo_model.ClearRepoStars(t.Context(), repo.ID))
 	unittest.AssertNotExistsBean(t, &repo_model.Star{UID: user.ID, RepoID: repo.ID})
 
-	gazers, err := repo_model.GetStargazers(db.DefaultContext, repo, db.ListOptions{Page: 0})
+	gazers, err := repo_model.GetStargazers(t.Context(), repo, db.ListOptions{Page: 0})
 	assert.NoError(t, err)
 	assert.Empty(t, gazers)
 }
