@@ -9,20 +9,20 @@ import (
 	"net/url"
 	"strings"
 
-	giturl "code.gitea.io/gitea/modules/git/url"
+	"code.gitea.io/gitea/modules/git/gitcmd"
 	"code.gitea.io/gitea/modules/util"
 )
 
 // GetRemoteAddress returns remote url of git repository in the repoPath with special remote name
 func GetRemoteAddress(ctx context.Context, repoPath, remoteName string) (string, error) {
-	var cmd *Command
+	var cmd *gitcmd.Command
 	if DefaultFeatures().CheckVersionAtLeast("2.7") {
-		cmd = NewCommand("remote", "get-url").AddDynamicArguments(remoteName)
+		cmd = gitcmd.NewCommand("remote", "get-url").AddDynamicArguments(remoteName)
 	} else {
-		cmd = NewCommand("config", "--get").AddDynamicArguments("remote." + remoteName + ".url")
+		cmd = gitcmd.NewCommand("config", "--get").AddDynamicArguments("remote." + remoteName + ".url")
 	}
 
-	result, _, err := cmd.RunStdString(ctx, &RunOpts{Dir: repoPath})
+	result, _, err := cmd.RunStdString(ctx, &gitcmd.RunOpts{Dir: repoPath})
 	if err != nil {
 		return "", err
 	}
@@ -33,15 +33,6 @@ func GetRemoteAddress(ctx context.Context, repoPath, remoteName string) (string,
 	return result, nil
 }
 
-// GetRemoteURL returns the url of a specific remote of the repository.
-func GetRemoteURL(ctx context.Context, repoPath, remoteName string) (*giturl.GitURL, error) {
-	addr, err := GetRemoteAddress(ctx, repoPath, remoteName)
-	if err != nil {
-		return nil, err
-	}
-	return giturl.ParseGitURL(addr)
-}
-
 // ErrInvalidCloneAddr represents a "InvalidCloneAddr" kind of error.
 type ErrInvalidCloneAddr struct {
 	Host               string
