@@ -4,15 +4,16 @@
 package httplib
 
 import (
-	"fmt"
 	"net/http"
 	"net/http/httptest"
 	"net/url"
 	"os"
+	"strconv"
 	"strings"
 	"testing"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestServeContentByReader(t *testing.T) {
@@ -22,14 +23,14 @@ func TestServeContentByReader(t *testing.T) {
 		_, rangeStr, _ := strings.Cut(t.Name(), "_range_")
 		r := &http.Request{Header: http.Header{}, Form: url.Values{}}
 		if rangeStr != "" {
-			r.Header.Set("Range", fmt.Sprintf("bytes=%s", rangeStr))
+			r.Header.Set("Range", "bytes="+rangeStr)
 		}
 		reader := strings.NewReader(data)
 		w := httptest.NewRecorder()
-		ServeContentByReader(r, w, "test", int64(len(data)), reader)
+		ServeContentByReader(r, w, int64(len(data)), reader, &ServeHeaderOptions{})
 		assert.Equal(t, expectedStatusCode, w.Code)
 		if expectedStatusCode == http.StatusPartialContent || expectedStatusCode == http.StatusOK {
-			assert.Equal(t, fmt.Sprint(len(expectedContent)), w.Header().Get("Content-Length"))
+			assert.Equal(t, strconv.Itoa(len(expectedContent)), w.Header().Get("Content-Length"))
 			assert.Equal(t, expectedContent, w.Body.String())
 		}
 	}
@@ -67,20 +68,18 @@ func TestServeContentByReadSeeker(t *testing.T) {
 		_, rangeStr, _ := strings.Cut(t.Name(), "_range_")
 		r := &http.Request{Header: http.Header{}, Form: url.Values{}}
 		if rangeStr != "" {
-			r.Header.Set("Range", fmt.Sprintf("bytes=%s", rangeStr))
+			r.Header.Set("Range", "bytes="+rangeStr)
 		}
 
 		seekReader, err := os.OpenFile(tmpFile, os.O_RDONLY, 0o644)
-		if !assert.NoError(t, err) {
-			return
-		}
+		require.NoError(t, err)
 		defer seekReader.Close()
 
 		w := httptest.NewRecorder()
-		ServeContentByReadSeeker(r, w, "test", nil, seekReader)
+		ServeContentByReadSeeker(r, w, nil, seekReader, &ServeHeaderOptions{})
 		assert.Equal(t, expectedStatusCode, w.Code)
 		if expectedStatusCode == http.StatusPartialContent || expectedStatusCode == http.StatusOK {
-			assert.Equal(t, fmt.Sprint(len(expectedContent)), w.Header().Get("Content-Length"))
+			assert.Equal(t, strconv.Itoa(len(expectedContent)), w.Header().Get("Content-Length"))
 			assert.Equal(t, expectedContent, w.Body.String())
 		}
 	}
