@@ -11,6 +11,6 @@ import (
 
 func TestIndexPos(t *testing.T) {
 	startIdx, endIdx := contentMatchIndexPos("test index start and end", "start", "end")
-	assert.EqualValues(t, 11, startIdx)
-	assert.EqualValues(t, 15, endIdx)
+	assert.Equal(t, 11, startIdx)
+	assert.Equal(t, 15, endIdx)
 }
