@@ -6,7 +6,6 @@ package system
 import (
 	"testing"
 
-	"code.gitea.io/gitea/models/db"
 	"code.gitea.io/gitea/models/unittest"
 
 	"github.com/stretchr/testify/assert"
@@ -37,25 +36,25 @@ func TestAppStateDB(t *testing.T) {
 	as := &DBStore{}
 
 	item1 := new(testItem1)
-	assert.NoError(t, as.Get(db.DefaultContext, item1))
+	assert.NoError(t, as.Get(t.Context(), item1))
 	assert.Empty(t, item1.Val1)
 	assert.Equal(t, 0, item1.Val2)
 
 	item1 = new(testItem1)
 	item1.Val1 = "a"
 	item1.Val2 = 2
-	assert.NoError(t, as.Set(db.DefaultContext, item1))
+	assert.NoError(t, as.Set(t.Context(), item1))
 
 	item2 := new(testItem2)
 	item2.K = "V"
-	assert.NoError(t, as.Set(db.DefaultContext, item2))
+	assert.NoError(t, as.Set(t.Context(), item2))
 
 	item1 = new(testItem1)
-	assert.NoError(t, as.Get(db.DefaultContext, item1))
+	assert.NoError(t, as.Get(t.Context(), item1))
 	assert.Equal(t, "a", item1.Val1)
 	assert.Equal(t, 2, item1.Val2)
 
 	item2 = new(testItem2)
-	assert.NoError(t, as.Get(db.DefaultContext, item2))
+	assert.NoError(t, as.Get(t.Context(), item2))
 	assert.Equal(t, "V", item2.K)
 }
