@@ -6,8 +6,9 @@ package validation
 import (
 	"testing"
 
+	"code.gitea.io/gitea/modules/glob"
+
 	"gitea.com/go-chi/binding"
-	"github.com/gobwas/glob"
 )
 
 func getGlobPatternErrorString(pattern string) string {
