@@ -12,7 +12,7 @@ import (
 
 	pingv1 "code.gitea.io/actions-proto-go/ping/v1"
 	"code.gitea.io/actions-proto-go/ping/v1/pingv1connect"
-	"github.com/bufbuild/connect-go"
+	"connectrpc.com/connect"
 )
 
 func NewPingServiceHandler() (string, http.Handler) {
@@ -21,9 +21,7 @@ func NewPingServiceHandler() (string, http.Handler) {
 
 var _ pingv1connect.PingServiceHandler = (*Service)(nil)
 
-type Service struct {
-	pingv1connect.UnimplementedPingServiceHandler
-}
+type Service struct{}
 
 func (s *Service) Ping(
 	ctx context.Context,
