@@ -6,7 +6,6 @@ package convert
 import (
 	"testing"
 
-	"code.gitea.io/gitea/models/db"
 	issues_model "code.gitea.io/gitea/models/issues"
 	"code.gitea.io/gitea/models/unittest"
 	user_model "code.gitea.io/gitea/models/user"
@@ -25,27 +24,27 @@ func Test_ToPullReview(t *testing.T) {
 	reviewList := []*issues_model.Review{review}
 
 	t.Run("Anonymous User", func(t *testing.T) {
-		prList, err := ToPullReviewList(db.DefaultContext, reviewList, nil)
+		prList, err := ToPullReviewList(t.Context(), reviewList, nil)
 		assert.NoError(t, err)
 		assert.Empty(t, prList)
 	})
 
 	t.Run("Reviewer Himself", func(t *testing.T) {
-		prList, err := ToPullReviewList(db.DefaultContext, reviewList, reviewer)
+		prList, err := ToPullReviewList(t.Context(), reviewList, reviewer)
 		assert.NoError(t, err)
 		assert.Len(t, prList, 1)
 	})
 
 	t.Run("Other User", func(t *testing.T) {
 		user4 := unittest.AssertExistsAndLoadBean(t, &user_model.User{ID: 4})
-		prList, err := ToPullReviewList(db.DefaultContext, reviewList, user4)
+		prList, err := ToPullReviewList(t.Context(), reviewList, user4)
 		assert.NoError(t, err)
 		assert.Empty(t, prList)
 	})
 
 	t.Run("Admin User", func(t *testing.T) {
 		adminUser := unittest.AssertExistsAndLoadBean(t, &user_model.User{ID: 1})
-		prList, err := ToPullReviewList(db.DefaultContext, reviewList, adminUser)
+		prList, err := ToPullReviewList(t.Context(), reviewList, adminUser)
 		assert.NoError(t, err)
 		assert.Len(t, prList, 1)
 	})
