@@ -32,24 +32,24 @@ func TestDeleteUser(t *testing.T) {
 		user := unittest.AssertExistsAndLoadBean(t, &user_model.User{ID: userID})
 
 		ownedRepos := make([]*repo_model.Repository, 0, 10)
-		assert.NoError(t, db.GetEngine(db.DefaultContext).Find(&ownedRepos, &repo_model.Repository{OwnerID: userID}))
+		assert.NoError(t, db.GetEngine(t.Context()).Find(&ownedRepos, &repo_model.Repository{OwnerID: userID}))
 		if len(ownedRepos) > 0 {
-			err := DeleteUser(db.DefaultContext, user, false)
+			err := DeleteUser(t.Context(), user, false)
 			assert.Error(t, err)
 			assert.True(t, repo_model.IsErrUserOwnRepos(err))
 			return
 		}
 
 		orgUsers := make([]*organization.OrgUser, 0, 10)
-		assert.NoError(t, db.GetEngine(db.DefaultContext).Find(&orgUsers, &organization.OrgUser{UID: userID}))
+		assert.NoError(t, db.GetEngine(t.Context()).Find(&orgUsers, &organization.OrgUser{UID: userID}))
 		for _, orgUser := range orgUsers {
 			org := unittest.AssertExistsAndLoadBean(t, &organization.Organization{ID: orgUser.OrgID})
-			if err := org_service.RemoveOrgUser(db.DefaultContext, org, user); err != nil {
+			if err := org_service.RemoveOrgUser(t.Context(), org, user); err != nil {
 				assert.True(t, organization.IsErrLastOrgOwner(err))
 				return
 			}
 		}
-		assert.NoError(t, DeleteUser(db.DefaultContext, user, false))
+		assert.NoError(t, DeleteUser(t.Context(), user, false))
 		unittest.AssertNotExistsBean(t, &user_model.User{ID: userID})
 		unittest.CheckConsistencyFor(t, &user_model.User{}, &repo_model.Repository{})
 	}
@@ -59,7 +59,7 @@ func TestDeleteUser(t *testing.T) {
 	test(11)
 
 	org := unittest.AssertExistsAndLoadBean(t, &user_model.User{ID: 3})
-	assert.Error(t, DeleteUser(db.DefaultContext, org, false))
+	assert.Error(t, DeleteUser(t.Context(), org, false))
 }
 
 func TestPurgeUser(t *testing.T) {
@@ -67,7 +67,7 @@ func TestPurgeUser(t *testing.T) {
 		assert.NoError(t, unittest.PrepareTestDatabase())
 		user := unittest.AssertExistsAndLoadBean(t, &user_model.User{ID: userID})
 
-		err := DeleteUser(db.DefaultContext, user, true)
+		err := DeleteUser(t.Context(), user, true)
 		assert.NoError(t, err)
 
 		unittest.AssertNotExistsBean(t, &user_model.User{ID: userID})
@@ -79,7 +79,7 @@ func TestPurgeUser(t *testing.T) {
 	test(11)
 
 	org := unittest.AssertExistsAndLoadBean(t, &user_model.User{ID: 3})
-	assert.Error(t, DeleteUser(db.DefaultContext, org, false))
+	assert.Error(t, DeleteUser(t.Context(), org, false))
 }
 
 func TestCreateUser(t *testing.T) {
@@ -92,9 +92,9 @@ func TestCreateUser(t *testing.T) {
 		MustChangePassword: false,
 	}
 
-	assert.NoError(t, user_model.CreateUser(db.DefaultContext, user, &user_model.Meta{}))
+	assert.NoError(t, user_model.CreateUser(t.Context(), user, &user_model.Meta{}))
 
-	assert.NoError(t, DeleteUser(db.DefaultContext, user, false))
+	assert.NoError(t, DeleteUser(t.Context(), user, false))
 }
 
 func TestRenameUser(t *testing.T) {
@@ -106,18 +106,18 @@ func TestRenameUser(t *testing.T) {
 			Type:      user_model.UserTypeIndividual,
 			LoginType: auth.OAuth2,
 		}
-		assert.ErrorIs(t, RenameUser(db.DefaultContext, u, "user_rename"), user_model.ErrUserIsNotLocal{})
+		assert.ErrorIs(t, RenameUser(t.Context(), u, "user_rename"), user_model.ErrUserIsNotLocal{})
 	})
 
 	t.Run("Same username", func(t *testing.T) {
-		assert.NoError(t, RenameUser(db.DefaultContext, user, user.Name))
+		assert.NoError(t, RenameUser(t.Context(), user, user.Name))
 	})
 
 	t.Run("Non usable username", func(t *testing.T) {
 		usernames := []string{"--diff", ".well-known", "gitea-actions", "aaa.atom", "aa.png"}
 		for _, username := range usernames {
 			assert.Error(t, user_model.IsUsableUsername(username), "non-usable username: %s", username)
-			assert.Error(t, RenameUser(db.DefaultContext, user, username), "non-usable username: %s", username)
+			assert.Error(t, RenameUser(t.Context(), user, username), "non-usable username: %s", username)
 		}
 	})
 
@@ -126,7 +126,7 @@ func TestRenameUser(t *testing.T) {
 		unittest.AssertNotExistsBean(t, &user_model.User{ID: user.ID, Name: caps})
 		unittest.AssertExistsAndLoadBean(t, &repo_model.Repository{OwnerID: user.ID, OwnerName: user.Name})
 
-		assert.NoError(t, RenameUser(db.DefaultContext, user, caps))
+		assert.NoError(t, RenameUser(t.Context(), user, caps))
 
 		unittest.AssertExistsAndLoadBean(t, &user_model.User{ID: user.ID, Name: caps})
 		unittest.AssertExistsAndLoadBean(t, &repo_model.Repository{OwnerID: user.ID, OwnerName: caps})
@@ -135,20 +135,20 @@ func TestRenameUser(t *testing.T) {
 	t.Run("Already exists", func(t *testing.T) {
 		existUser := unittest.AssertExistsAndLoadBean(t, &user_model.User{ID: 1})
 
-		assert.ErrorIs(t, RenameUser(db.DefaultContext, user, existUser.Name), user_model.ErrUserAlreadyExist{Name: existUser.Name})
-		assert.ErrorIs(t, RenameUser(db.DefaultContext, user, existUser.LowerName), user_model.ErrUserAlreadyExist{Name: existUser.LowerName})
+		assert.ErrorIs(t, RenameUser(t.Context(), user, existUser.Name), user_model.ErrUserAlreadyExist{Name: existUser.Name})
+		assert.ErrorIs(t, RenameUser(t.Context(), user, existUser.LowerName), user_model.ErrUserAlreadyExist{Name: existUser.LowerName})
 		newUsername := fmt.Sprintf("uSEr%d", existUser.ID)
-		assert.ErrorIs(t, RenameUser(db.DefaultContext, user, newUsername), user_model.ErrUserAlreadyExist{Name: newUsername})
+		assert.ErrorIs(t, RenameUser(t.Context(), user, newUsername), user_model.ErrUserAlreadyExist{Name: newUsername})
 	})
 
 	t.Run("Normal", func(t *testing.T) {
 		oldUsername := user.Name
 		newUsername := "User_Rename"
 
-		assert.NoError(t, RenameUser(db.DefaultContext, user, newUsername))
+		assert.NoError(t, RenameUser(t.Context(), user, newUsername))
 		unittest.AssertExistsAndLoadBean(t, &user_model.User{ID: user.ID, Name: newUsername, LowerName: strings.ToLower(newUsername)})
 
-		redirectUID, err := user_model.LookupUserRedirect(db.DefaultContext, oldUsername)
+		redirectUID, err := user_model.LookupUserRedirect(t.Context(), oldUsername)
 		assert.NoError(t, err)
 		assert.Equal(t, user.ID, redirectUID)
 
@@ -175,24 +175,24 @@ func TestCreateUser_Issue5882(t *testing.T) {
 	for _, v := range tt {
 		setting.Admin.DisableRegularOrgCreation = v.disableOrgCreation
 
-		assert.NoError(t, user_model.CreateUser(db.DefaultContext, v.user, &user_model.Meta{}))
+		assert.NoError(t, user_model.CreateUser(t.Context(), v.user, &user_model.Meta{}))
 
-		u, err := user_model.GetUserByEmail(db.DefaultContext, v.user.Email)
+		u, err := user_model.GetUserByEmail(t.Context(), v.user.Email)
 		assert.NoError(t, err)
 
 		assert.Equal(t, !u.AllowCreateOrganization, v.disableOrgCreation)
 
-		assert.NoError(t, DeleteUser(db.DefaultContext, v.user, false))
+		assert.NoError(t, DeleteUser(t.Context(), v.user, false))
 	}
 }
 
 func TestDeleteInactiveUsers(t *testing.T) {
 	addUser := func(name, email string, createdUnix timeutil.TimeStamp, active bool) {
 		inactiveUser := &user_model.User{Name: name, LowerName: strings.ToLower(name), Email: email, CreatedUnix: createdUnix, IsActive: active}
-		_, err := db.GetEngine(db.DefaultContext).NoAutoTime().Insert(inactiveUser)
+		_, err := db.GetEngine(t.Context()).NoAutoTime().Insert(inactiveUser)
 		assert.NoError(t, err)
 		inactiveUserEmail := &user_model.EmailAddress{UID: inactiveUser.ID, IsPrimary: true, Email: email, LowerEmail: strings.ToLower(email), IsActivated: active}
-		err = db.Insert(db.DefaultContext, inactiveUserEmail)
+		err = db.Insert(t.Context(), inactiveUserEmail)
 		assert.NoError(t, err)
 	}
 	addUser("user-inactive-10", "user-inactive-10@test.com", timeutil.TimeStampNow().Add(-600), false)
@@ -201,7 +201,7 @@ func TestDeleteInactiveUsers(t *testing.T) {
 	addUser("user-active-5", "user-active-5@test.com", timeutil.TimeStampNow().Add(-300), true)
 	unittest.AssertExistsAndLoadBean(t, &user_model.User{Name: "user-inactive-10"})
 	unittest.AssertExistsAndLoadBean(t, &user_model.EmailAddress{Email: "user-inactive-10@test.com"})
-	assert.NoError(t, DeleteInactiveUsers(db.DefaultContext, 8*time.Minute))
+	assert.NoError(t, DeleteInactiveUsers(t.Context(), 8*time.Minute))
 	unittest.AssertNotExistsBean(t, &user_model.User{Name: "user-inactive-10"})
 	unittest.AssertNotExistsBean(t, &user_model.EmailAddress{Email: "user-inactive-10@test.com"})
 	unittest.AssertExistsAndLoadBean(t, &user_model.User{Name: "user-inactive-5"})
