@@ -13,7 +13,6 @@ import (
 	"strings"
 	"testing"
 
-	"code.gitea.io/gitea/models/db"
 	"code.gitea.io/gitea/models/packages"
 	"code.gitea.io/gitea/models/unittest"
 	user_model "code.gitea.io/gitea/models/user"
@@ -150,11 +149,11 @@ func TestPackageSwift(t *testing.T) {
 			`{"name":"`+packageName+`","version":"`+packageVersion+`","description":"`+packageDescription+`","codeRepository":"`+packageRepositoryURL+`","author":{"givenName":"`+packageAuthor+`"},"repositoryURLs":["`+packageRepositoryURL+`"]}`,
 		)
 
-		pvs, err := packages.GetVersionsByPackageType(db.DefaultContext, user.ID, packages.TypeSwift)
+		pvs, err := packages.GetVersionsByPackageType(t.Context(), user.ID, packages.TypeSwift)
 		assert.NoError(t, err)
 		assert.Len(t, pvs, 1)
 
-		pd, err := packages.GetPackageDescriptor(db.DefaultContext, pvs[0])
+		pd, err := packages.GetPackageDescriptor(t.Context(), pvs[0])
 		assert.NoError(t, err)
 		assert.NotNil(t, pd.SemVer)
 		assert.Equal(t, packageID, pd.Package.Name)
@@ -168,7 +167,7 @@ func TestPackageSwift(t *testing.T) {
 		assert.Len(t, pd.VersionProperties, 1)
 		assert.Equal(t, packageRepositoryURL, pd.VersionProperties.GetByName(swift_module.PropertyRepositoryURL))
 
-		pfs, err := packages.GetFilesByVersionID(db.DefaultContext, pvs[0].ID)
+		pfs, err := packages.GetFilesByVersionID(t.Context(), pvs[0].ID)
 		assert.NoError(t, err)
 		assert.Len(t, pfs, 1)
 		assert.Equal(t, fmt.Sprintf("%s-%s.zip", packageName, packageVersion), pfs[0].Name)
@@ -238,11 +237,11 @@ func TestPackageSwift(t *testing.T) {
 			`{"name":"`+packageName+`","version":"`+packageVersion2+`","description":"`+packageDescription+`","codeRepository":"`+packageRepositoryURL+`","author":{"givenName":"`+packageAuthor+`"},"repositoryURLs":["`+packageRepositoryURL+`"]}`,
 		)
 
-		pvs, err := packages.GetVersionsByPackageType(db.DefaultContext, user.ID, packages.TypeSwift)
+		pvs, err := packages.GetVersionsByPackageType(t.Context(), user.ID, packages.TypeSwift)
 		assert.NoError(t, err)
 		require.Len(t, pvs, 2) // ATTENTION: many subtests are unable to run separately, they depend on the results of previous tests
 		thisPackageVersion := pvs[0]
-		pd, err := packages.GetPackageDescriptor(db.DefaultContext, thisPackageVersion)
+		pd, err := packages.GetPackageDescriptor(t.Context(), thisPackageVersion)
 		assert.NoError(t, err)
 		assert.NotNil(t, pd.SemVer)
 		assert.Equal(t, packageID, pd.Package.Name)
@@ -256,7 +255,7 @@ func TestPackageSwift(t *testing.T) {
 		assert.Len(t, pd.VersionProperties, 1)
 		assert.Equal(t, packageRepositoryURL, pd.VersionProperties.GetByName(swift_module.PropertyRepositoryURL))
 
-		pfs, err := packages.GetFilesByVersionID(db.DefaultContext, thisPackageVersion.ID)
+		pfs, err := packages.GetFilesByVersionID(t.Context(), thisPackageVersion.ID)
 		assert.NoError(t, err)
 		assert.Len(t, pfs, 1)
 		assert.Equal(t, fmt.Sprintf("%s-%s.zip", packageName, packageVersion2), pfs[0].Name)
@@ -284,11 +283,11 @@ func TestPackageSwift(t *testing.T) {
 		assert.Equal(t, "1", resp.Header().Get("Content-Version"))
 		assert.Equal(t, "application/zip", resp.Header().Get("Content-Type"))
 
-		pv, err := packages.GetVersionByNameAndVersion(db.DefaultContext, user.ID, packages.TypeSwift, packageID, packageVersion)
+		pv, err := packages.GetVersionByNameAndVersion(t.Context(), user.ID, packages.TypeSwift, packageID, packageVersion)
 		assert.NotNil(t, pv)
 		assert.NoError(t, err)
 
-		pd, err := packages.GetPackageDescriptor(db.DefaultContext, pv)
+		pd, err := packages.GetPackageDescriptor(t.Context(), pv)
 		assert.NoError(t, err)
 		assert.Equal(t, "sha256="+pd.Files[0].Blob.HashSHA256, resp.Header().Get("Digest"))
 	})
@@ -337,11 +336,11 @@ func TestPackageSwift(t *testing.T) {
 		var result *swift_router.PackageVersionMetadataResponse
 		DecodeJSON(t, resp, &result)
 
-		pv, err := packages.GetVersionByNameAndVersion(db.DefaultContext, user.ID, packages.TypeSwift, packageID, packageVersion)
+		pv, err := packages.GetVersionByNameAndVersion(t.Context(), user.ID, packages.TypeSwift, packageID, packageVersion)
 		assert.NotNil(t, pv)
 		assert.NoError(t, err)
 
-		pd, err := packages.GetPackageDescriptor(db.DefaultContext, pv)
+		pd, err := packages.GetPackageDescriptor(t.Context(), pv)
 		assert.NoError(t, err)
 
 		assert.Equal(t, packageID, result.ID)
