@@ -4,13 +4,13 @@
 package integration
 
 import (
+	"context"
 	"fmt"
 	"net/http"
 	"net/url"
 	"testing"
 
 	auth_model "code.gitea.io/gitea/models/auth"
-	"code.gitea.io/gitea/models/db"
 	repo_model "code.gitea.io/gitea/models/repo"
 	unit_model "code.gitea.io/gitea/models/unit"
 	"code.gitea.io/gitea/models/unittest"
@@ -22,6 +22,7 @@ import (
 
 // getRepoEditOptionFromRepo gets the options for an existing repo exactly as is
 func getRepoEditOptionFromRepo(repo *repo_model.Repository) *api.EditRepoOption {
+	ctx := context.TODO()
 	name := repo.Name
 	description := repo.Description
 	website := repo.Website
@@ -29,7 +30,7 @@ func getRepoEditOptionFromRepo(repo *repo_model.Repository) *api.EditRepoOption
 	hasIssues := false
 	var internalTracker *api.InternalTracker
 	var externalTracker *api.ExternalTracker
-	if unit, err := repo.GetUnit(db.DefaultContext, unit_model.TypeIssues); err == nil {
+	if unit, err := repo.GetUnit(ctx, unit_model.TypeIssues); err == nil {
 		config := unit.IssuesConfig()
 		hasIssues = true
 		internalTracker = &api.InternalTracker{
@@ -37,7 +38,7 @@ func getRepoEditOptionFromRepo(repo *repo_model.Repository) *api.EditRepoOption
 			AllowOnlyContributorsToTrackTime: config.AllowOnlyContributorsToTrackTime,
 			EnableIssueDependencies:          config.EnableDependencies,
 		}
-	} else if unit, err := repo.GetUnit(db.DefaultContext, unit_model.TypeExternalTracker); err == nil {
+	} else if unit, err := repo.GetUnit(ctx, unit_model.TypeExternalTracker); err == nil {
 		config := unit.ExternalTrackerConfig()
 		hasIssues = true
 		externalTracker = &api.ExternalTracker{
@@ -49,13 +50,12 @@ func getRepoEditOptionFromRepo(repo *repo_model.Repository) *api.EditRepoOption
 	}
 	hasWiki := false
 	var externalWiki *api.ExternalWiki
-	if _, err := repo.GetUnit(db.DefaultContext, unit_model.TypeWiki); err == nil {
+	if _, err := repo.GetUnit(ctx, unit_model.TypeWiki); err == nil {
 		hasWiki = true
-	} else if unit, err := repo.GetUnit(db.DefaultContext, unit_model.TypeExternalWiki); err == nil {
+	} else if unit, err := repo.GetUnit(ctx, unit_model.TypeExternalWiki); err == nil {
 		hasWiki = true
-		config := unit.ExternalWikiConfig()
 		externalWiki = &api.ExternalWiki{
-			ExternalWikiURL: config.ExternalWikiURL,
+			ExternalWikiURL: unit.ExternalWikiConfig().ExternalWikiURL,
 		}
 	}
 	defaultBranch := repo.DefaultBranch
@@ -66,7 +66,7 @@ func getRepoEditOptionFromRepo(repo *repo_model.Repository) *api.EditRepoOption
 	allowRebaseMerge := false
 	allowSquash := false
 	allowFastForwardOnly := false
-	if unit, err := repo.GetUnit(db.DefaultContext, unit_model.TypePullRequests); err == nil {
+	if unit, err := repo.GetUnit(ctx, unit_model.TypePullRequests); err == nil {
 		config := unit.PullRequestsConfig()
 		hasPullRequests = true
 		ignoreWhitespaceConflicts = config.IgnoreWhitespaceConflicts
@@ -77,12 +77,36 @@ func getRepoEditOptionFromRepo(repo *repo_model.Repository) *api.EditRepoOption
 		allowFastForwardOnly = config.AllowFastForwardOnly
 	}
 	archived := repo.IsArchived
+	hasProjects := false
+	var projectsMode *string
+	if unit, err := repo.GetUnit(ctx, unit_model.TypeProjects); err == nil && unit != nil {
+		hasProjects = true
+		pm := string(unit.ProjectsConfig().ProjectsMode)
+		projectsMode = &pm
+	}
+	hasCode := repo.UnitEnabled(ctx, unit_model.TypeCode)
+	hasPackages := repo.UnitEnabled(ctx, unit_model.TypePackages)
+	hasReleases := repo.UnitEnabled(ctx, unit_model.TypeReleases)
+	hasActions := false
+	if unit, err := repo.GetUnit(ctx, unit_model.TypeActions); err == nil && unit != nil {
+		hasActions = true
+		// TODO: expose action config of repo to api
+		// actionsConfig = &api.RepoActionsConfig{
+		// 	DisabledWorkflows: unit.ActionsConfig().DisabledWorkflows,
+		// }
+	}
 	return &api.EditRepoOption{
 		Name:                      &name,
 		Description:               &description,
 		Website:                   &website,
 		Private:                   &private,
 		HasIssues:                 &hasIssues,
+		HasProjects:               &hasProjects,
+		ProjectsMode:              projectsMode,
+		HasCode:                   &hasCode,
+		HasPackages:               &hasPackages,
+		HasReleases:               &hasReleases,
+		HasActions:                &hasActions,
 		ExternalTracker:           externalTracker,
 		InternalTracker:           internalTracker,
 		HasWiki:                   &hasWiki,
@@ -109,6 +133,11 @@ func getNewRepoEditOption(opts *api.EditRepoOption) *api.EditRepoOption {
 	private := !*opts.Private
 	hasIssues := !*opts.HasIssues
 	hasWiki := !*opts.HasWiki
+	hasProjects := !*opts.HasProjects
+	hasCode := !*opts.HasCode
+	hasPackages := !*opts.HasPackages
+	hasReleases := !*opts.HasReleases
+	hasActions := !*opts.HasActions
 	defaultBranch := "master"
 	hasPullRequests := !*opts.HasPullRequests
 	ignoreWhitespaceConflicts := !*opts.IgnoreWhitespaceConflicts
@@ -126,6 +155,11 @@ func getNewRepoEditOption(opts *api.EditRepoOption) *api.EditRepoOption {
 		DefaultBranch:             &defaultBranch,
 		HasIssues:                 &hasIssues,
 		HasWiki:                   &hasWiki,
+		HasProjects:               &hasProjects,
+		HasCode:                   &hasCode,
+		HasPackages:               &hasPackages,
+		HasReleases:               &hasReleases,
+		HasActions:                &hasActions,
 		HasPullRequests:           &hasPullRequests,
 		IgnoreWhitespaceConflicts: &ignoreWhitespaceConflicts,
 		AllowMerge:                &allowMerge,
@@ -157,6 +191,11 @@ func TestAPIRepoEdit(t *testing.T) {
 
 		// Test editing a repo1 which user2 owns, changing name and many properties
 		origRepoEditOption := getRepoEditOptionFromRepo(repo1)
+		assert.True(t, *origRepoEditOption.HasCode)
+		assert.True(t, *origRepoEditOption.HasPackages)
+		assert.True(t, *origRepoEditOption.HasProjects)
+		assert.True(t, *origRepoEditOption.HasReleases)
+		assert.True(t, *origRepoEditOption.HasActions)
 		repoEditOption := getNewRepoEditOption(origRepoEditOption)
 		req := NewRequestWithJSON(t, "PATCH", fmt.Sprintf("/api/v1/repos/%s/%s", user2.Name, repo1.Name), &repoEditOption).
 			AddTokenAuth(token2)
@@ -178,6 +217,11 @@ func TestAPIRepoEdit(t *testing.T) {
 		assert.Equal(t, *repoEditOption.Archived, *repo1editedOption.Archived)
 		assert.Equal(t, *repoEditOption.Private, *repo1editedOption.Private)
 		assert.Equal(t, *repoEditOption.HasWiki, *repo1editedOption.HasWiki)
+		assert.Equal(t, *repoEditOption.HasCode, *repo1editedOption.HasCode)
+		assert.Equal(t, *repoEditOption.HasPackages, *repo1editedOption.HasPackages)
+		assert.Equal(t, *repoEditOption.HasProjects, *repo1editedOption.HasProjects)
+		assert.Equal(t, *repoEditOption.HasReleases, *repo1editedOption.HasReleases)
+		assert.Equal(t, *repoEditOption.HasActions, *repo1editedOption.HasActions)
 
 		// Test editing repo1 to use internal issue and wiki (default)
 		*repoEditOption.HasIssues = true
@@ -225,6 +269,11 @@ func TestAPIRepoEdit(t *testing.T) {
 		assert.Equal(t, *repo1editedOption.ExternalTracker, *repoEditOption.ExternalTracker)
 		assert.True(t, *repo1editedOption.HasWiki)
 		assert.Equal(t, *repo1editedOption.ExternalWiki, *repoEditOption.ExternalWiki)
+		assert.False(t, *repo1editedOption.HasCode)
+		assert.False(t, *repo1editedOption.HasPackages)
+		assert.False(t, *repo1editedOption.HasProjects)
+		assert.False(t, *repo1editedOption.HasReleases)
+		assert.False(t, *repo1editedOption.HasActions)
 
 		repoEditOption.ExternalTracker.ExternalTrackerStyle = "regexp"
 		repoEditOption.ExternalTracker.ExternalTrackerRegexpPattern = `(\d+)`
@@ -273,6 +322,11 @@ func TestAPIRepoEdit(t *testing.T) {
 		assert.NotNil(t, *repo1editedOption.ExternalTracker)
 		assert.True(t, *repo1editedOption.HasWiki)
 		assert.NotNil(t, *repo1editedOption.ExternalWiki)
+		assert.False(t, *repo1editedOption.HasCode)
+		assert.False(t, *repo1editedOption.HasPackages)
+		assert.False(t, *repo1editedOption.HasProjects)
+		assert.False(t, *repo1editedOption.HasReleases)
+		assert.False(t, *repo1editedOption.HasActions)
 
 		// reset repo in db
 		req = NewRequestWithJSON(t, "PATCH", fmt.Sprintf("/api/v1/repos/%s/%s", user2.Name, *repoEditOption.Name), &origRepoEditOption).
