@@ -7,7 +7,6 @@ import (
 	"testing"
 
 	"code.gitea.io/gitea/models/auth"
-	"code.gitea.io/gitea/models/db"
 	"code.gitea.io/gitea/models/unittest"
 	"code.gitea.io/gitea/tests"
 
@@ -21,16 +20,16 @@ func Test_RegenerateSession(t *testing.T) {
 
 	key := "new_key890123456"  // it must be 16 characters long
 	key2 := "new_key890123457" // it must be 16 characters
-	exist, err := auth.ExistSession(db.DefaultContext, key)
+	exist, err := auth.ExistSession(t.Context(), key)
 	assert.NoError(t, err)
 	assert.False(t, exist)
 
-	sess, err := auth.RegenerateSession(db.DefaultContext, "", key)
+	sess, err := auth.RegenerateSession(t.Context(), "", key)
 	assert.NoError(t, err)
 	assert.Equal(t, key, sess.Key)
 	assert.Empty(t, sess.Data)
 
-	sess, err = auth.ReadSession(db.DefaultContext, key2)
+	sess, err = auth.ReadSession(t.Context(), key2)
 	assert.NoError(t, err)
 	assert.Equal(t, key2, sess.Key)
 	assert.Empty(t, sess.Data)
