@@ -16,7 +16,7 @@ func TestSignOut(t *testing.T) {
 	session := loginUser(t, "user2")
 
 	req := NewRequest(t, "POST", "/user/logout")
-	session.MakeRequest(t, req, http.StatusSeeOther)
+	session.MakeRequest(t, req, http.StatusOK)
 
 	// try to view a private repo, should fail
 	req = NewRequest(t, "GET", "/user2/repo2")
