@@ -11,7 +11,6 @@ import (
 	"net/http"
 	"testing"
 
-	"code.gitea.io/gitea/models/db"
 	"code.gitea.io/gitea/models/unittest"
 	user_model "code.gitea.io/gitea/models/user"
 	"code.gitea.io/gitea/modules/avatar"
@@ -74,7 +73,7 @@ func TestUserAvatar(t *testing.T) {
 
 	user2 = unittest.AssertExistsAndLoadBean(t, &user_model.User{ID: 2}) // owner of the repo3, is an org
 
-	req = NewRequest(t, "GET", user2.AvatarLinkWithSize(db.DefaultContext, 0))
+	req = NewRequest(t, "GET", user2.AvatarLinkWithSize(t.Context(), 0))
 	_ = session.MakeRequest(t, req, http.StatusOK)
 
 	testGetAvatarRedirect(t, user2)
