@@ -4,6 +4,8 @@ import {initMarkupCodeCopy} from './codecopy.ts';
 import {initMarkupRenderAsciicast} from './asciicast.ts';
 import {initMarkupTasklist} from './tasklist.ts';
 import {registerGlobalSelectorFunc} from '../modules/observer.ts';
+import {initMarkupRenderIframe} from './render-iframe.ts';
+import {initMarkupRefIssue} from './refissue.ts';
 
 // code that runs for all markup content
 export function initMarkupContent(): void {
@@ -13,5 +15,7 @@ export function initMarkupContent(): void {
     initMarkupCodeMermaid(el);
     initMarkupCodeMath(el);
     initMarkupRenderAsciicast(el);
+    initMarkupRenderIframe(el);
+    initMarkupRefIssue(el);
   });
 }
