@@ -1,17 +1,10 @@
-import {pathEscapeSegments, isUrl, toOriginUrl} from './url.ts';
+import {pathEscapeSegments, toOriginUrl} from './url.ts';
 
 test('pathEscapeSegments', () => {
   expect(pathEscapeSegments('a/b/c')).toEqual('a/b/c');
   expect(pathEscapeSegments('a/b/ c')).toEqual('a/b/%20c');
 });
 
-test('isUrl', () => {
-  expect(isUrl('https://example.com')).toEqual(true);
-  expect(isUrl('https://example.com/')).toEqual(true);
-  expect(isUrl('https://example.com/index.html')).toEqual(true);
-  expect(isUrl('/index.html')).toEqual(false);
-});
-
 test('toOriginUrl', () => {
   const oldLocation = String(window.location);
   for (const origin of ['https://example.com', 'https://example.com:3000']) {
